##  What's Changing
For a detailed overview of changes, refer to:
  * [Key Changes](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api?locale=en-US&state=PRODUCTION&version=CLOUD#loiob13f241cc2e847d6b4ec3201fb4cf786__key_changes)
  * [Breaking Changes](https://help.sap.com/docs/leanix/ea/poll-api-updates-transition-to-new-survey-api?locale=en-US&state=PRODUCTION&version=CLOUD#loiob13f241cc2e847d6b4ec3201fb4cf786__breaking_changes)
